from distutils.core import setup

setup(
  name = 'pydval',
  packages = ['pydval'],
  version = '0.0.2',
  license='MIT',
  description = 'Python Data Validator',
  author = 'Afrizal F.A',
  author_email = 'afrizal.fadillah46@gmail.com',
  url = 'https://github.com/ICWR-TECH/Pydval',
  download_url = 'https://github.com/ICWR-TECH/Pydval/raw/master/pydval-0.0.2.tar.gz',
  keywords = ['pydval'],
  classifiers=[
    'Development Status :: 3 - Alpha',
    'Intended Audience :: Developers',
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3.8',
  ],
)
